Mesh.Shards.HashStrategy.EventualConsistency (Mesh v0.1.4)

Eventual consistency hash strategy using modulo distribution.

Distributes shards across nodes using rem(shard, node_count). When nodes are added or removed, ownership changes cause the same process ID to temporarily exist on multiple nodes until the system converges (eventual consistency).

This is the default strategy.